# Copyright (c) 2009 Microsoft Corporation. All rights reserved.
# THIS CODE IS MADE AVAILABLE AS IS, WITHOUT WARRANTY OF ANY KIND. THE ENTIRE RISK OF THE USE OR THE RESULTS FROM THE USE OF THIS CODE REMAINS WITH THE USER.
# This is a filter registration script to configure Exchange Server 2010 to index Office 2007 file formats. 
$DLLPath = $env:CommonProgramFiles + "\Microsoft Shared\Filters"
$CLSIDKey = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\V14\MSSearch\CLSID"
$FiltersKey = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\v14\MSSearch\Filters"

# Filter DLL Locations
$officeFilterLocation = $DLLPath + "\offfiltx.dll"
$onenoteFilterLocation = $DLLPath + "\ONIFilter.dll"
$visioFilterLocation = $DLLPath + "\VISFilt.DLL"

# Filter GUIDs
$docxGuid    ="{5A98B233-3C59-4B31-944C-0E560D85E6C3}"
$pptxGuid    ="{DDFE337F-4987-4EC8-BDE3-133FA63D5D85}"
$xlsxGuid    ="{F90DFE0C-CBDF-41FF-8598-EDD8F222A2C8}"
$zipGuid     ="{20E823C2-62F3-4638-96BD-90F4F6784EBC}"
$xlsbGuid    ="{312AB530-ECC9-496E-AE0E-C9E6C5392499}"
$onenoteGuid ="{B8D12492-CE0F-40AD-83EA-099A03D493F1}"
$vsdGuid     ="{FAEA5B46-761B-400E-B53E-E805A97A543E}"

# Create CLSIDs
Write-Host "Creating CLSIDs..."

New-Item -Path $CLSIDKey -Name $docxGuid -Value $officeFilterLocation -Type String
New-Item -Path $CLSIDKey -Name $pptxGuid  -Value $officeFilterLocation -Type String
New-Item -Path $CLSIDKey -Name $xlsxGuid  -Value $officeFilterLocation -Type String
New-Item -Path $CLSIDKey -Name $zipGuid  -Value $officeFilterLocation -Type String
New-Item -Path $CLSIDKey -Name $xlsbGuid -Value $officeFilterLocation -Type String
New-Item -Path $CLSIDKey -Name $onenoteGuid -Value $onenoteFilterLocation -Type String
New-Item -Path $CLSIDKey -Name $vsdGuid  -Value $visioFilterLocation -Type String

# Set Threading model
Write-Host "Setting threading model..."

New-ItemProperty -Path "$CLSIDKey\$docxGuid" -Name "ThreadingModel" -Value "Both" -Type String
New-ItemProperty -Path "$CLSIDKey\$pptxGuid" -Name "ThreadingModel" -Value "Both" -Type String
New-ItemProperty -Path "$CLSIDKey\$xlsxGuid" -Name "ThreadingModel" -Value "Both" -Type String
New-ItemProperty -Path "$CLSIDKey\$zipGuid" -Name "ThreadingModel" -Value "Both" -Type String
New-ItemProperty -Path "$CLSIDKey\$xlsbGuid" -Name "ThreadingModel" -Value "Both" -Type String
New-ItemProperty -Path "$CLSIDKey\$onenoteGuid" -Name "ThreadingModel" -Value "Both" -Type String
New-ItemProperty -Path "$CLSIDKey\$vsdGuid" -Name "ThreadingModel" -Value "Both" -Type String

# Create Filter Entries
Write-Host "Creating Filter Entries..."

# Uncomment these if you wish to index these uncommonly exchanged formats
#New-Item -Path $FiltersKey -Name ".docm" -Value $docxGuid -Type String
#New-Item -Path $FiltersKey -Name ".pptm" -Value $pptxGuid -Type String
#New-Item -Path $FiltersKey -Name ".xlsm" -Value $xlsxGuid -Type String
#New-Item -Path $FiltersKey -Name ".vss" -Value $vsdGuid   -Type String
#New-Item -Path $FiltersKey -Name ".vst" -Value $vsdGuid   -Type String
#New-Item -Path $FiltersKey -Name ".vsx" -Value $vsdGuid   -Type String
#New-Item -Path $FiltersKey -Name ".vtx" -Value $vsdGuid   -Type String

# These are the entries for commonly exchange formats
New-Item -Path $FiltersKey -Name ".docx" -Value $docxGuid -Type String
New-Item -Path $FiltersKey -Name ".pptx" -Value $pptxGuid -Type String
New-Item -Path $FiltersKey -Name ".xlsx" -Value $xlsxGuid -Type String
New-Item -Path $FiltersKey -Name ".xlsb" -Value $xlsbGuid -Type String
New-Item -Path $FiltersKey -Name ".zip" -Value $zipGuid  -Type String
New-Item -Path $FiltersKey -Name ".one" -Value $onenoteGuid -Type String
New-Item -Path $FiltersKey -Name ".vsd" -Value $vsdGuid   -Type String

Write-Host "Registry subkeys created."
Write-Host "Please restart Microsoft Search  (Exchange) service from the Services console, or by running stop-service msftesql-Exchange -Force ; start-service MSExchangeSearch "
